@@ -1,37 +1,33 @@
 #include "rossler_sim.h"
 #include <grs.h>
 
-#include <boost/bind.hpp>
 #include <iostream>
 #include <fstream>
 
-class RosslerGrs : public Grs::ButtonBoxWindow, public RosslerSim
+class RosslerGrs : public Grs::ButtonBox, public RosslerSim
 {
 public:
     typedef RosslerGrs Self;
 
     RosslerGrs()
-        // window Υȥ
-        : Grs::ButtonBoxWindow("Rossler"), RosslerSim(),
-          parlist("parlist"), varlist("varlist"), graph("graph", 2),
         // line 򥰥դϿ
-          g(), line1(graph[0]), line2(graph[1])
+        : graph(2), line1(graph[0]), line2(graph[1])
     {
         // Ͽؿ¹Ԥܥ
-        add_func("Quit", boost::bind(&Self::hide, this));
 
-        // дؿϿ -- boost::bind 
-        // this->step() ¹Ԥޤ
-        add_func("Step", boost::bind(&Self::step, this));
+        // this->hide() ¹Ԥޤ
+        add_func("Quit", sigc::mem_fun(this, &Self::hide));
 
-        // дؿϿ -- boost::bind 
         // this->step() ¹Ԥޤ
-        add_file_selection("Save", boost::bind(&Self::save, this, _1));
+        add_func("Step", sigc::mem_fun(this, &Self::step));
+
+        // this->save() ¹Ԥޤ
+        add_file_selection("Save", sigc::mem_fun(this, &Self::save));
 
         // åɤϿ -- START/STOP ܥޤ
         // ¹ϡϿؿ򷫤֤¹Ԥޤ
         // Ͽؿ false ֤STOP ܥ򲡤Ȥǽλ
-        add_thread("", boost::bind(&Self::run, this));
+        add_thread("", sigc::mem_fun(this, &Self::run));
 
         // ե饰Ͽ
         add_toggle("Output", out_flag);
@@ -41,14 +37,18 @@ public:
         // Grs::rw ꤹѹǽޤ
         parlist << dt << rep_num << a << b << c << Grs::ro << dt;
         // parlist window ɽ/ɽؤܥϿޤ
-        add_window(parlist);
+        parwin.set_title("Par");
+        parwin.add(parlist);
+        add_window(parwin);
 
         // varlist window ˥ѥ᡼Ͽޤ
         // Grs::set_digits(int) Ǿʲηꤷޤ
         varlist << Grs::set_digits(1) << t
                 << Grs::set_digits(6) << x << y << z;
         // varlist window ɽ/ɽؤܥϿޤ
-        add_window(varlist);
+        varwin.set_title("Var");
+        varwin.add(varlist);
+        add_window(varwin);
 
         // graph 
         graph[0].x1 = -10.0;
@@ -57,7 +57,9 @@ public:
         graph[0].y2 =  10.0;
         graph[1].y1 =  -5.0;
         graph[1].y2 =  25.0;
-        add_window(graph);
+        graphwin.set_title("Graph");
+        graphwin.add(graph);
+        add_window(graphwin);
 
         // line 
         line1.property_fill_color().set_value("red");
@@ -74,13 +76,15 @@ public:
         integrate(g);
         // integrate λ򥰥դαü
         graph[1].x2 = double(t);
-        // x-y -> line1
-        // Index(0) = x, Index(1) = y
-        line1.property_points().set_value(
-                g.get_points(Grs::Index(0), Grs::Index(1)));
-        // t-z -> line2
-        // g.get_points : ҤȤĤ x  t 
-        line2.property_points().set_value(g.get_points(Grs::Index(2)));
+        if (g.get_points(Grs::Index(0)).size() >= 2) {
+            // x-y -> line1
+            // Index(0) = x, Index(1) = y
+            line1.property_points()
+                .set_value(g.get_points(Grs::Index(0), Grs::Index(1)));
+            // t-z -> line2
+            // g.get_points : ҤȤĤ x  t 
+            line2.property_points().set_value(g.get_points(Grs::Index(2)));
+        }
 
         // out_flag  on ʤɸϤ
         if (out_flag) std::cout << g;
@@ -102,21 +106,27 @@ public:
 
 private:
     Grs::Property<bool> out_flag;
-    Grs::ValueListWindow parlist;
-    Grs::ValueListWindow varlist;
-    Grs::GraphWindow       graph;
+    Gtk::Window parwin;
+    Grs::ValueList parlist;
+    Gtk::Window varwin;
+    Grs::ValueList varlist;
+    Gtk::Window graphwin;
+    Grs::GraphCanvas graph;
     Grs::GraphStream g;
-    Gnome::Canvas::Line    line1;
-    Gnome::Canvas::Line    line2;
+    Gnome::Canvas::Line line1;
+    Gnome::Canvas::Line line2;
 };
 
 int
 main(int argc, char** argv)
 {
     Grs::Main app(argc, argv);
+    Gtk::Window win;
+    win.set_title("grstest");
     RosslerGrs sim;
-    sim.show_all();
-    app.run(sim);
+    win.add(sim);
+    win.show_all();
+    app.run(win);
     return 0;
 }
 
