@@ -1,5 +1,5 @@
 #include <grs/graphstream.h>
-#include <grs/graphwindow.h>
+#include <grs/graphcanvas.h>
 #include <cmath>
 
 void
@@ -24,29 +24,29 @@ make_image(Grs::Graph& graph, Grs::GridImage& image)
     x0 += 5.0;
 }
 
-#include <libgnomecanvasmm/init.h>
-#include <gtkmm/main.h>
-#include <grs/buttonboxwindow.h>
-
-#include <boost/bind.hpp>
-using boost::bind;
-using boost::ref;
+#include <grs/main.h>
+#include <grs/buttonbox.h>
 
 int
 main(int argc, char** argv)
 {
-    Gnome::Canvas::init();
-    Gtk::Main app(argc, argv);
+    Grs::Main app(argc, argv);
 
     Grs::GridImage image;
-    Grs::GraphWindow graph("graph", 1);
-    graph.set_default_size(200, 200);
+    Gtk::Window graphwin;
+    graphwin.set_default_size(200, 200);
+    graphwin.set_title("graph");
+    Grs::GraphCanvas graph(1);
+    graphwin.add(graph);
 
-    Grs::ButtonBoxWindow win("graphtest");
-    win.add_func("step", bind(&make_image, ref(graph[0]), ref(image)));
-    win.add_window(graph);
+    Gtk::Window win;
+    win.set_title("graphtest");
+    Grs::ButtonBox box;
+    box.add_func("step", bind(&make_image, ref(graph[0]), ref(image)));
+    box.add_window(graphwin);
+    win.add(box);
     win.show_all();
 
-    Gtk::Main::run(win);
+    Grs::Main::run(win);
     return 0;
 }
