@@ -12,10 +12,6 @@
 #include <grs/togglebutton.h>
 #include <grs/windowbutton.h>
 
-#include <grs/buttonboxwindow.h>
-#include <grs/valuelistwindow.h>
-#include <grs/graphwindow.h>
-
 #include <grs/entryint.h>
 #include <grs/entryreal.h>
 
