@@ -21,10 +21,6 @@
 #include "entryint.h"
 #include <gdk/gdkkeysyms.h>
 
-#include <boost/bind.hpp>
-using boost::bind;
-using boost::ref;
-
 namespace {
 
 const int pow_10[] = {
@@ -64,8 +60,8 @@ EntryInt::EntryInt(Property<int>& property)
     init_text();
     init_cursol();
 
-    property.connect(boost::bind(&EntryInt::set_value, this, _1));
-    m_signal.connect(boost::bind(&Property<int>::set_value, &property, _1));
+    property.connect(sigc::group(sigc::mem_fun(this, &EntryInt::set_value), sigc::_1));
+    m_signal.connect(sigc::group(sigc::mem_fun(&property, &Property<int>::set_value), sigc::_1));
 }
 
 EntryInt::~EntryInt()
