@@ -52,7 +52,7 @@ protected:
 private:
     int m_value;
     int m_position;
-    boost::signal<void (int)> m_signal;
+    sigc::signal<void, int> m_signal;
     Glib::RefPtr<Pango::Layout> m_layout;
 
     void init_text();
