@@ -19,10 +19,9 @@
  */
 
 #include "entryreal.h"
+#include <cmath>
 #include <gdk/gdkkeysyms.h>
 
-#include <boost/bind.hpp>
-
 namespace Grs {
 
 namespace {
@@ -58,8 +57,8 @@ EntryReal::EntryReal(Property<double>& property, int digits)
     set_digits(digits);
     init_text();
 
-    property.connect(boost::bind(&EntryReal::set_value, this, _1));
-    m_signal.connect(boost::bind(&Property<double>::set_value, &property, _1));
+    property.connect(sigc::group(sigc::mem_fun(this, &EntryReal::set_value), sigc::_1));
+    m_signal.connect(sigc::group(sigc::mem_fun(&property, &Property<double>::set_value), sigc::_1));
 }
 
 EntryReal::~EntryReal()
