@@ -56,7 +56,7 @@ private:
     int m_position;
     double m_value;
     Glib::RefPtr<Pango::Layout> m_layout;
-    boost::signal<void(double)> m_signal;
+    sigc::signal<void, double> m_signal;
 
     void init_text();
     void init_cursol();
