@@ -25,7 +25,7 @@ namespace Grs {
 WindowButton::WindowButton(Gtk::Window& win)
     : Gtk::ToggleButton(win.get_title()), m_win(win)
 {
-    win.signal_hide().connect(SigC::bind(SigC::slot(*this, &Gtk::ToggleButton::set_active), false));
+    win.signal_hide().connect(sigc::bind(sigc::mem_fun(*this, &Gtk::ToggleButton::set_active), false));
 }
 
 WindowButton::~WindowButton()
